@@ -33,7 +33,8 @@ func TestHouseKeepingMessagesNotShownForDiagnose(t *testing.T) {
 func TestHouseKeepingMessagesShownForDev(t *testing.T) {
 	MarkIntegrationTest(t, CanRunWithoutGcp)
 	file := testutil.TempFile(t, "config", nil)
-	out := skaffold.Run("-c", file, "--update-check=true").InDir("examples/getting-started").RunOrFailOutput(t)
+	out, err := skaffold.Run("-c", file, "--update-check=true").InDir("examples/getting-started").RunWithCombinedOutput(t)
+	testutil.CheckError(t, false, err)
 	testutil.CheckContains(t, "Help improve Skaffold", string(out))
 	skaffold.Delete().InDir("examples/getting-started").Run(t)
 }
