@@ -17,12 +17,15 @@ limitations under the License.
 package docker
 
 import (
+	"context"
 	"strings"
 	"sync"
 
 	"github.com/docker/cli/cli/config"
 	"github.com/google/go-containerregistry/pkg/authn"
 	"github.com/google/go-containerregistry/pkg/v1/google"
+
+	"github.com/GoogleContainerTools/skaffold/v2/pkg/skaffold/output/log"
 )
 
 var primaryKeychain = &Keychain{
@@ -76,17 +79,17 @@ func (a *lockedAuthenticator) Authorization() (*authn.AuthConfig, error) {
 }
 
 // Create a new authenticator for a given reference
-// 1. If `gcloud` is configured, we use google.NewGcloudAuthenticator(). It is more efficient because it reuses tokens.
+// 1. If `gcloud` is configured with given registry, we try to use a Google authenticator
 // 2. If something else is configured, we use that authenticator
 // 3. If nothing is configured, we check if `gcloud` can be used
 // 4. Default to anonymous
 func (a *Keychain) newAuthenticator(res authn.Resource) authn.Authenticator {
 	registry := res.RegistryStr()
 
-	// 1. Use google.NewGcloudAuthenticator() authenticator if `gcloud` is configured
+	// 1. Try getting a Google authenticator if docker config configured to use gcloud
 	cfg, err := config.Load(a.configDir)
 	if err == nil && cfg.CredentialHelpers[registry] == "gcloud" {
-		if auth, err := google.NewGcloudAuthenticator(); err == nil {
+		if auth := getGoogleAuthenticator(); auth != nil {
 			return auth
 		}
 	}
@@ -97,9 +100,9 @@ func (a *Keychain) newAuthenticator(res authn.Resource) authn.Authenticator {
 		return auth
 	}
 
-	// 3. Try gcloud for *.gcr.io
-	if registry == "gcr.io" || strings.HasSuffix(registry, ".gcr.io") {
-		if auth, err := google.NewGcloudAuthenticator(); err == nil {
+	// 3. Try Google authenticator for known registries (same logic used by go-containerregistry)
+	if isGoogleRegistry(registry) {
+		if auth := getGoogleAuthenticator(); auth != nil {
 			return auth
 		}
 	}
@@ -107,3 +110,36 @@ func (a *Keychain) newAuthenticator(res authn.Resource) authn.Authenticator {
 	// 4. Default to anonymous
 	return authn.Anonymous
 }
+
+func getGoogleAuthenticator() authn.Authenticator {
+	// 1. First we try to create an authenticator that uses Application Default Credentials
+	auth, err := google.NewEnvAuthenticator()
+	if err == nil && auth != authn.Anonymous {
+		log.Entry(context.TODO()).Debugf("using Application Default Credentials authenticator")
+		return auth
+	}
+
+	if err != nil {
+		log.Entry(context.TODO()).Debugf("failed to get Application Default Credentials auth: %v", err)
+	}
+
+	// 2. Try to create authenticator that uses gcloud
+	auth, err = google.NewGcloudAuthenticator()
+	if err == nil && auth != authn.Anonymous {
+		log.Entry(context.TODO()).Debugf("using gcloud authenticator")
+		return auth
+	}
+
+	if err != nil {
+		log.Entry(context.TODO()).Debugf("failed to get gcloud auth: %v", err)
+	}
+
+	return nil
+}
+
+func isGoogleRegistry(host string) bool {
+	return host == "gcr.io" ||
+		strings.HasSuffix(host, ".gcr.io") ||
+		strings.HasSuffix(host, ".pkg.dev") ||
+		strings.HasSuffix(host, ".google.com")
+}
